@@ -110,9 +110,9 @@ fi
 ( cd opt/kde/lib ; rm -rf libkio.so.4 )
 ( cd opt/kde/lib ; ln -sf libkio.so.4.1.0 libkio.so.4 )
 ( cd opt/kde/share/doc/HTML/en/kdelibs-apidocs ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kdelibs-apidocs ; ln -sf /root/kde-3.1.2/kdelibs/temp/opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kdelibs-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kspell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kspell ; ln -sf /root/kde-3.1.2/kdelibs/temp/opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kspell ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/icons ; rm -rf default.kde )
 ( cd opt/kde/share/icons ; ln -sf crystalsvg default.kde )
 ( cd opt/kde/include/kdesu ; rm -rf pty.h )
