@@ -23,6 +23,8 @@ public:
     virtual ASYNC FilesRemoved( const KURL::List& fileList );
     virtual ASYNC FilesChanged( const KURL::List& fileList );
     virtual ASYNC FileRenamed( const KURL& src, const KURL& dst );
+protected:
+    KDirNotify_stub() : DCOPStub( never_use ) {};
 };
 
 
